#
# spec file for package libqmi
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libqmi
%define _soname libqmi-glib1
Version:        1.12.8
Release:        1.2
# NOTE: The file headers state LESSER GPL, which is a mistake. The upstream intended license is LIBRARY GPL 2.0+
Summary:        Library to control QMI devices
License:        LGPL-2.1+ and GPL-2.0+
Group:          Hardware/Modem
Url:            http://cgit.freedesktop.org/libqmi/
Source0:        http://www.freedesktop.org/software/libqmi/%{name}-%{version}.tar.xz
Source99:       libqmi-rpmlintrc
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gobject-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

%package -n %{_soname}
Summary:        Library to control QMI devices
Group:          System/Libraries
# The tools are a useful addition
Recommends:     %{name}-tools

%description -n %{_soname}
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

%package tools
Summary:        Helper utilities to control QMI devices
Group:          Hardware/Modem

%description tools
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

This package contains command line tools to manage such devices.

%package devel
Summary:        Library to control QMI devices -- Development files
Group:          Development/Languages/C and C++
Requires:       %{_soname} = %{version}

%description devel
A GLib/GIO based library to control QMI devices

This package contains files required to link sources against libqmi.

%prep
%setup -q

%build
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print

%post -n %{_soname} -p /sbin/ldconfig

%postun -n %{_soname} -p /sbin/ldconfig

%files tools
%defattr(-,root,root)
%doc COPYING
%{_bindir}/qmi-network
%{_bindir}/qmicli
%{_libexecdir}/qmi-proxy
%{_mandir}/man1/qmi-network.1%{?ext_man}
%{_mandir}/man1/qmicli.1%{?ext_man}

%files -n %{_soname}
%defattr(-,root,root)
%doc COPYING.LIB
%{_libdir}/libqmi-glib.so.*

%files devel
%defattr(-,root,root)
%{_datadir}/gtk-doc/html/libqmi-glib/
%{_includedir}/libqmi-glib/
%{_libdir}/libqmi-glib.so
%{_libdir}/pkgconfig/qmi-glib.pc

%changelog
* Wed Mar 23 2016 jengelh@inai.de
- Improve description; say what QMI is
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 1.12.8:
  + codegen: fix bug which was limiting the transaction ID of
    request messages generated to just 8bits.
  + device: try to debug-print raw invalid QMI messages too.
  + Additional bugfixes:
  - build: avoid C++ reserved keywords.
  - nas: correct ID for Get RF Band Information result TLV.
  - qmicli: fix PLMN printing.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 1.12.6:
  + Fix big-endian handling of tlv->length.
* Wed Feb 25 2015 mgorse@suse.com
- Added COPYING and COPYING.LIB and fixed license attribute for
  debug utils
* Wed Feb 11 2015 zaitor@opensuse.org
- Update to version 1.12.4:
  + Fix reading last call packet statistics.
  + Added support for the "DMS Set FCC" command, required to bring
    out of low power mode several new Sierra devices.
* Sun Feb  1 2015 zaitor@opensuse.org
- Update to version 1.12.2:
  + Fix bug reading sized-guints, which was making --dms-get-time
    segfault.
  + Fix compilation warnings in 32 bit systems.
  + Add missing services in get_printable() and
    get_version_introduced().
* Wed Jan 28 2015 dimstar@opensuse.org
- Update to version 1.12.0:
  + New `--enable-qmi-username' option during configure, which
    allows specifying which will be the user owning the
    /dev/cdc-wdm character devices of all QMI modems (udev rules
    are installed to change file ownership). If this option is
    used, the qmi-proxy will only allow connections from processes
    running by the specified user or by the root user.
  + New TLV builder and reader API, which is much more strict and
    secure. The autogenerated code will no longer first check if
    there is enough space available in the output message buffer
    and then write the parsed contents. Instead, the new reader API
    will be used, which is able to check for the expected size
    directly before writing in the buffer.
  + New unit tests to check messages built by the libqmi-glib
    library, using a fake proxy. In order to support these, the
    QmiDevice has two new properties:
  - "device-no-file-check": instructs the QmiDevice to avoid
    checking if the specified file exists.
  - "device-proxy-path": specifies a custom abstract socket path
    for the QmiProxy, to avoid using the default one.
  + New A-GPS support in the PDS service:
  - pds: added "Get Default Tracking Session" request/response.
  - pds: added "Set Default Tracking Session" request/response.
  - pds: added "Get AGPS Config" request/response.
  - pds: added "Set AGPS Config" request/response.
  + Updated minumum available version of several messages:
  - dms: "UIM Get IMSI" seems to be available in DMS 1.1 already.
  - dms: "UIM Get ICCID" seems to be available in DMS 1.1
    already.
  + Other bugfixes and minor improvements:
  - Attach timeout and idle events to the thread-default context.
  - Fix bashisms in the qmi-network script.
  - Fix qmi_message_set_transaction_id() in non-CTL messages.
  - Fix segfault due to race condition in the QmiProxy.
  - Fixed printing contents of structs with fixed sized strings
    in qmi-codegen.
- Drop libqmi-1.10.2-fix-bashisms.patch: fixed upstream.
* Thu Nov 27 2014 Led <ledest@gmail.com>
- fix bashisms in qmi-network script
- add patches:
  * libqmi-1.10.2-fix-bashisms.patch
* Mon Oct  6 2014 mardnh@gmx.de
- Update to version 1.10.2:
  + release: bump version to 1.10.2
  + build: update NEWS
  + cli,nas: S/N ratio is dB, not dBm
  + cli,nas: limit resolution when printing floating point numbers
  + cli,nas: fix constant out of range issue in comparison
  + cli,nas: fix unmatched format specifiers
  + release: post release version bump to 1.10.1
  + release: bump version to 1.10.0
  + cli,nas: decode BCD-encoded PLMN and print it
  + cli,nas: pretty print field types
  + cli,nas: don't print fields with unknown data
  + cli,nas: add missing indentations
  + nas: add 'UMTS Info Neighboring LTE' TLV to 'Cell Location Info'
  + nas: fix several TLV field types
  + nas: consolidate variable names
  + nas: add missing TLV field
  + nas: trivial fixes in indentation and alignment
  + docs,libqmi-glib: add 'NAS Get Cell Location Info' documentation
  + qmi-codegen: handle 'gfloat' types
  + qmicli: fix wrong array reference cutnpaste bug
  + qmicli: add NAS Get Cell Location Info
  + nas: add "Get Cell Location Info"
  + libqmi-glib,proxy: update internal default timeout value
  + cli,wda: new '--wda-set-data-format' action
  + cli,wda: fix error string message
  + libqmi,wda: rename enum to "_RAW_IP" to match the name in the CTL service
  + wda: implement 'Set Data Format' request/response
  + cli,wda: new '--wda-get-data-format' action
  + wda: new 'WDA' service
  + cli: new '--uim-get-card-status' action
  + uim: implement "Get Card Status"
  + data: add libqmi icon
  + license: add GPLv2+ license in addition to the LGPLv2+ one
  + build-aux,qmi-codegen: explicitly state which services have flags64
  + libqmi-glib,device: print as debug flags used when opening or releasing client
  + qmicli: add '--device-open-net' option
  + libqmi-glib: generate types for QmiDeviceOpenFlags and QmiDeviceReleaseClientFlags
* Sun Jan 26 2014 zaitor@opensuse.org
- Update to version 1.8.0:
  + This version comes with one small API break: Enum value
    QMI_SERVICE_RMTFS is not 0x14, but 14.
  + Support for sharing the QMI port through multiple processes
    with the new 'qmi-proxy' infrastructure.
  + api: Added new known service ID enumeration values.
  + wds: Added "Get Profile List", "Get Profile Settings", "Get
    Default Settings" request/response.
  + cli: Add --wds-get-profile-list & --wds-get-default-settings.
  + man: Added qmi-network manpage, autogenerated from --help-all.
- Changes from version 1.6.0:
  + This version comes with one small API break: dms: 'SID' TLV in
    "Activate Manual" is a guint8, not a string.
  + Extended API with macros to check for the libqmi-glib version
    in use.
  + Setup libtool versioning in libqmi-glib.
  + Added initial support for the PBM (phonebook) service.
  + Added initial support for the UIM service.
  + Added initial support for the OMA (Open Mobile Alliance)
    service.
  + nas: added "Get Tx Rx Info" request/response.
  + wds: added "Get Packet Statistics" request/response.
  + dms: added support for the 'PRL' TLV in "Activate Manual".
  + cli: add --nas-get-tx-rx-info, --wds-get-packet-statistics,
  - -get-service-version-info, --uim-read-transparent,
  - -uim-get-file-attributes.
  + cli: fix following network status until disconnected.
  + tests: use gtester to run unit tests.
  + man: added qmicli manpage, autogenerated from --help-all.
  + Also fixed several minor bugs and memory leaks.
- Bump soname following upstream changes, this means that
  package libqmi-glib0 will be renamed to libqmi-glib1.
* Wed Jan 22 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + dms: fix minimum version requirement for DMS Get/Set Operating
    Mode.
  + nas: added 'Network Time' indication.
  + utils: fix reading sized uints in BE systems.
  + cli: add --dms-activate-manual.
  + cli: implemented setting System Selection Preference.
  + cli: fix technology preference persistence reporting.
  + cli: fix reading new PIN in '--dms-uim-change-pin'.
  + docs: always generate documentation at dist time.
  + tests: fixed BE/LE tests in BE systems.
- Changes from version 1.2.0:
  + Builds with Python3.
  + Fixed DMS activation code string handling.
  + Enhanced "start network" functionality in qmicli.
* Mon Dec 10 2012 dimstar@opensuse.org
- Initial package, release 1.0.
